@@ -8,8 +8,7 @@ from cryptomodel.notification_type import NOTIFICATION_TYPE
 '''
 Represents a a computed_user_notification 
 Holds a notification 
-Extends by holding the computed_date 
-Result is programmatically added 
+Extends by holding the computed_date and the string value of json 
 '''
 
 
@@ -18,10 +17,16 @@ class computed_notification(user_notification):
     computed_date = DateField()
     result = StringField()
 
+    sent = BooleanField(default=False)
+
     def set_result(self, value, computed_date):
         self.result = value
         self.computed_date = computed_date
 
+    '''
+    returns the equivalent object of the json stored in the result field  
+    '''
+
     def get_result(self):
         if not hasattr(self, "result"):
             raise ValueError("does not exist : result ")
